==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/tr-TR/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Aksesuar Zimmet Kabul',
    'Accessory_Checkout_Notification' => 'Aksesuar teslim alındı',
    'Asset_Checkin_Notification' => 'Varlık Zimmet Kabul',
    'Asset_Checkout_Notification' => 'Varlık teslim alındı',
    'Confirm_Accessory_Checkin' => 'Aksesuar giriş onayı',
    'Confirm_Asset_Checkin' => 'Varlık Kabul Onayı',
    'Confirm_accessory_delivery' => 'Aksesuar teslimat onayı',
    'Confirm_asset_delivery' => 'Varlık Kabul Onayı',
    'Confirm_consumable_delivery' => 'Sarf malzemesi teslimat onayı',
    'Confirm_license_delivery' => 'Lisans teslim onayı',
    'Consumable_checkout_notification' => 'Sarf malzeme teslim alındı',
    'Days' => 'Günler',
    'Expected_Checkin_Date' => 'Size teslim edilen bir varlık :date tarihinde tekrar teslim edilecektir',
    'Expected_Checkin_Notification' => 'Hatırlatma ::name Son seçim zamanı yaklaşıyor',
    'Expected_Checkin_Report' => 'Beklenen varlık iade raporu',
    'Expiring_Assets_Report' => 'Süresi Dolan Varlık Raporu.',
    'Expiring_Licenses_Report' => 'Süresi Dolan Lisans Raporu.',
    'Item_Request_Canceled' => 'Talep İptal Edildi',
    'Item_Requested' => 'Varlık Talep Edildi',
    'License_Checkin_Notification' => 'Lisans Zimmet Kabul',
    'License_Checkout_Notification' => 'Lisans teslim alındı',
    'Low_Inventory_Report' => 'Düşük Stok Raporu',
    'a_user_canceled' => 'Bir kullanıcı web sitede öğe talebinden vazgeçti',
    'a_user_requested' => 'Bir kullanıcı websitede bir öğe talebinde bulundu',
    'acceptance_asset_accepted' => 'Kullanıcı bir öğeyi kabul etti',
    'acceptance_asset_declined' => 'Kullanıcı bir öğeyi reddetti',
    'accessory_name' => 'Aksesuar Adı',
    'additional_notes' => 'Ek Notlar',
    'admin_has_created' => 'Bir yönetici sizin için :web site\'de bir hesap oluşturdu.',
    'asset' => 'Demirbaş',
    'asset_name' => 'Demirbaş Adı',
    'asset_requested' => 'İstenen varlık',
    'asset_tag' => 'Varlık Adı',
    'assets_warrantee_alert' => 'Şu var: gelecek vadede garanti süresi dolmuş varlık sayımı: eşik günler. | Şunlar var: gelecek yıl sona ermesi garantili varlıklar sayılır: eşik günleri.',
    'assigned_to' => 'Atanmış',
    'best_regards' => 'En iyi dileklerimizle,',
    'canceled' => 'İptal edildi',
    'checkin_date' => 'Giriş Tarihi',
    'checkout_date' => 'Çıkış Tarihi',
    'checkedout_from' => 'Teslim alınan kişi',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Çıkış yapılan',
    'click_on_the_link_accessory' => 'Lütfen aşağıdaki bağlantıya tıklayarak aksesuar talebinizi onaylayın.',
    'click_on_the_link_asset' => 'Lütfen aşağıdaki bağlantıya tıklayarak varlık talebinizi onaylayın.',
    'click_to_confirm' => 'Lütfen :hesabınızı: onaylamak için aşağıdaki linke tıklayınız:',
    'current_QTY' => 'Mevcut miktar',
    'days' => 'Günler',
    'expecting_checkin_date' => 'Beklenen geri alma tarihi',
    'expires' => 'Bitiş',
    'hello' => 'Merhaba',
    'hi' => 'Merhaba',
    'i_have_read' => 'Okudum ve kullanım şartlarını ve bu varlığı kabul ediyorum.',
    'inventory_report' => 'Envanter Raporu',
    'item' => 'Ürün',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Şu var: bir sonraki günlerde süren lisans sayımı: eşik günleri. | Şunlar var: bir sonraki günlerde süren sayım lisansları: eşik günleri.',
    'link_to_update_password' => 'Şifrenizi güncellemek için aşağıdaki linke tıklayınız :web password:',
    'login' => 'Giriş:',
    'login_first_admin' => 'Yeni Snipe-IT Kurulumu oturum açma kimlik bilgilerini aşağıdaki gibidir. ',
    'low_inventory_alert' => 'Şu var: Minimum envanterin altında olan veya yakında düşük olacak olan sayı maddesi. | Şunlar var: Minimum envanterin altında olan veya yakında olacak olan sayım maddeleri.',
    'min_QTY' => 'Min. Miktar',
    'name' => 'Ad',
    'new_item_checked' => 'Yeni varlık altında kullanıma alındı, ayrıntıları aşağıdadır.',
    'notes' => 'Notlar',
    'password' => 'Şifre',
    'password_reset' => 'Parola Sıfırlama',
    'read_the_terms' => 'Aşağıdaki kullanım koşullarını okuyunuz.',
    'read_the_terms_and_click' => 'Lütfen aşağıdaki kullanım koşullarını okuyun ve kullanım koşullarını okuyup kabul ettiğinizi, demirbaşı teslim aldığınızı onaylamak için alttaki bağlantıya tıklayın.',
    'requested' => 'Talep Edilen',
    'reset_link' => 'Parola Sıfırlama Bağlantısı',
    'reset_password' => 'Şifrenizi sıfırlamak için burayı tıklatın:',
    'rights_reserved' => 'Her türlü hakkı saklıdır.',
    'serial' => 'Seri',
    'snipe_webhook_test' => 'Snipe-IT Entegrasyon Testi',
    'snipe_webhook_summary' => 'Snipe-IT Entegrasyon Test Özeti',
    'supplier' => 'Tedarikçi',
    'tag' => 'Etiket',
    'test_email' => 'Snipe-It Test Maili',
    'test_mail_text' => 'Snipe-IT varlık yönetim sisteminden bir denemedir',
    'the_following_item' => 'Aşağıdaki varlık geri alındı olarak işaretlendi: ',
    'to_reset' => 'Şifre sıfırlamak için :web password, formu doldurun:',
    'type' => 'Tür',
    'upcoming-audits' => ':count gün içinde denetime yaklaşan :count varlık var.|Eşik gün içinde denetime yaklaşan :count varlık var.',
    'user' => 'Kullanıcı',
    'username' => 'Kullanıcı Adı',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Hoşgeldiniz, :name',
    'welcome_to' => 'Hoş geldiniz :web!',
    'your_assets' => 'Varlıkları Görüntüleme',
    'your_credentials' => 'Snipe-IT Bilgileriniz',
    'mail_sent' => 'E-posta başarılı şekilde gönderildi!',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/tr-TR/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Aksesuar Zimmet Kabul',
    'Accessory_Checkout_Notification' => 'Accessory checked out|:count Accessories checked out',
    'Asset_Checkin_Notification' => 'Asset checked in: :tag',
    'Asset_Checkout_Notification' => 'Asset checked out: :tag',
    'Confirm_Accessory_Checkin' => 'Aksesuar giriş onayı',
    'Confirm_Asset_Checkin' => 'Varlık Kabul Onayı',
    'Confirm_component_checkin' => 'Component checkin confirmation',
    'Confirm_accessory_delivery' => 'Aksesuar teslimat onayı',
    'Confirm_asset_delivery' => 'Varlık Kabul Onayı',
    'Confirm_consumable_delivery' => 'Sarf malzemesi teslimat onayı',
    'Confirm_component_delivery' => 'Component delivery confirmation',
    'Confirm_license_delivery' => 'Lisans teslim onayı',
    'Consumable_checkout_notification' => 'Sarf malzeme teslim alındı',
    'Component_checkout_notification' => 'Component checked out',
    'Component_checkin_notification' => 'Component checked in',
    'Days' => 'Günler',
    'Expected_Checkin_Date' => 'Size teslim edilen bir varlık :date tarihinde tekrar teslim edilecektir',
    'Expected_Checkin_Notification' => 'Hatırlatma ::name Son seçim zamanı yaklaşıyor',
    'Expected_Checkin_Report' => 'Beklenen varlık iade raporu',
    'Expiring_Assets_Report' => 'Süresi Dolan Varlık Raporu',
    'Expiring_Licenses_Report' => 'Süresi Dolan Lisans Raporu',
    'Item_Request_Canceled' => 'Talep İptal Edildi',
    'Item_Requested' => 'Varlık Talep Edildi',
    'License_Checkin_Notification' => 'Lisans Zimmet Kabul',
    'License_Checkout_Notification' => 'Lisans teslim alındı',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'Düşük Stok Raporu',
    'a_user_canceled' => 'Bir kullanıcı web sitede öğe talebinden vazgeçti',
    'a_user_requested' => 'Bir kullanıcı websitede bir öğe talebinde bulundu',
    'acceptance_asset_accepted_to_user' => 'You have accepted an item assigned to you by :site_name|You have accepted :qty items assigned to you by :site_name',
    'acceptance_asset_accepted' => 'Kullanıcı bir öğeyi kabul etti',
    'acceptance_asset_declined' => 'Kullanıcı bir öğeyi reddetti',
    'send_pdf_copy' => 'Send a copy of this acceptance to my email address',
    'accessory_name' => 'Aksesuar Adı',
    'additional_notes' => 'Ek Notlar',
    'admin_has_created' => 'An administrator has created an account for you on the :web website. Please find your username below, and click on the link to set a password.',
    'asset' => 'Demirbaş',
    'asset_name' => 'Demirbaş Adı',
    'asset_requested' => 'İstenen varlık',
    'asset_tag' => 'Varlık Adı',
    'assets_warrantee_alert' => 'There is :count asset with an expiring warranty or that are reaching their end of life in the next :threshold days.|There are :count assets with expiring warranties or that are reaching their end of life in the next :threshold days.',
    'assigned_to' => 'Atanmış',
    'eol' => 'Ömür Süresi',
    'best_regards' => 'En iyi dileklerimizle,',
    'canceled' => 'İptal edildi',
    'checkin_date' => 'Giriş Tarihi',
    'checkout_date' => 'Çıkış Tarihi',
    'checkedout_from' => 'Teslim alınan kişi',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Çıkış yapılan',
    'click_on_the_link_accessory' => 'Lütfen aşağıdaki bağlantıya tıklayarak aksesuar talebinizi onaylayın.',
    'click_on_the_link_asset' => 'Lütfen aşağıdaki bağlantıya tıklayarak varlık talebinizi onaylayın.',
    'click_to_confirm' => 'Lütfen :hesabınızı: onaylamak için aşağıdaki linke tıklayınız:',
    'current_QTY' => 'Mevcut miktar',
    'days' => 'Günler',
    'expecting_checkin_date' => 'Beklenen geri alma tarihi',
    'expires' => 'Bitiş',
    'terminates' => 'Terminates',
    'following_accepted' => 'The following was accepted',
    'following_declined' => 'The following was declined',
    'hello' => 'Merhaba',
    'hi' => 'Merhaba',
    'i_have_read' => 'Okudum ve kullanım şartlarını ve bu varlığı kabul ediyorum.',
    'initiated_accepted' => 'A checkout you initiated was accepted',
    'initiated_declined' => 'A checkout you initiated was declined',
    'inventory_report' => 'Envanter Raporu',
    'item' => 'Ürün',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring or terminating in the next :threshold days.|There are :count licenses expiring or terminating in the next :threshold days.',
    'link_to_update_password' => 'Şifrenizi güncellemek için aşağıdaki linke tıklayınız :web password:',
    'login' => 'Giriş',
    'login_first_admin' => 'Yeni Snipe-IT Kurulumu oturum açma kimlik bilgilerini aşağıdaki gibidir. ',
    'low_inventory_alert' => 'Şu var: Minimum envanterin altında olan veya yakında düşük olacak olan sayı maddesi. | Şunlar var: Minimum envanterin altında olan veya yakında olacak olan sayım maddeleri.',
    'min_QTY' => 'Min. Miktar',
    'name' => 'Ad',
    'new_item_checked' => 'A new item has been checked out under your name, details are below.|:count new items have been checked out under your name, details are below.',
    'new_item_checked_with_acceptance' => 'A new item has been checked out under your name that requires acceptance, details are below.|:count new items have been checked out under your name that requires acceptance, details are below.',
    'new_item_checked_location' => 'A new item has been checked out to :location, details are below.|:count new items have been checked out to :location, details are below.',
    'recent_item_checked' => 'An item was recently checked out under your name that requires acceptance, details are below.',
    'notes' => 'Notlar',
    'password' => 'Şifre',
    'password_reset' => 'Parola Sıfırlama',
    'read_the_terms' => 'Aşağıdaki kullanım koşullarını okuyunuz.',
    'read_the_terms_and_click' => 'Lütfen aşağıdaki kullanım koşullarını okuyun ve kullanım koşullarını okuyup kabul ettiğinizi, demirbaşı teslim aldığınızı onaylamak için alttaki bağlantıya tıklayın.',
    'requested' => 'Talep Edilen',
    'reset_link' => 'Parola Sıfırlama Bağlantısı',
    'reset_password' => 'Şifrenizi sıfırlamak için burayı tıklatın:',
    'rights_reserved' => 'Her türlü hakkı saklıdır.',
    'serial' => 'Seri',
    'snipe_webhook_test' => 'Snipe-IT Entegrasyon Testi',
    'snipe_webhook_summary' => 'Snipe-IT Entegrasyon Test Özeti',
    'supplier' => 'Tedarikçi',
    'tag' => 'Etiket',
    'test_email' => 'Snipe-It Test Maili',
    'test_mail_text' => 'Snipe-IT varlık yönetim sisteminden bir denemedir',
    'the_following_item' => 'Aşağıdaki varlık geri alındı olarak işaretlendi: ',
    'to_reset' => 'Şifre sıfırlamak için :web password, formu doldurun:',
    'type' => 'Tür',
    'upcoming-audits' => ':count gün içinde denetime yaklaşan :count varlık var.|Eşik gün içinde denetime yaklaşan :count varlık var.',
    'user' => 'Kullanıcı',
    'username' => 'Kullanıcı Adı',
    'unaccepted_asset_reminder' => 'Reminder: You have Unaccepted Assets.',
    'welcome' => 'Hoşgeldiniz, :name',
    'welcome_to' => 'Hoş geldiniz :web!',
    'your_assets' => 'Varlıkları Görüntüleme',
    'your_credentials' => 'Snipe-IT Bilgileriniz',
    'mail_sent' => 'E-posta başarılı şekilde gönderildi!',
];
